@@ -15,9 +15,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -486,7 +484,7 @@ response_cb (GtkDialog *dialog,
     {
     case GTK_RESPONSE_HELP:
       gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (dialog)),
-                    "help:gnome-dictionary/gnome-dictionary-preferences",
+                    "help:gnome-dictionary/pref",
                     gtk_get_current_event_time (), &err);
       if (err)
 	{
